pub struct LlmCurator<L: LlmGenerate + Send + Sync> { /* private fields */ }Expand description
Production curator. Wraps an OllamaClient (or any
crate::autonomy::AutonomyLlm-like surface — we re-use the
existing generate shape via a free function rather than coupling
to the autonomy trait, because the autonomy trait does not expose
generate(prompt, system)).
Implementations
Sourceimpl<L: LlmGenerate + Send + Sync> LlmCurator<L>
impl<L: LlmGenerate + Send + Sync> LlmCurator<L>