pub fn render_regression_table(rows: &[Regression]) -> StringExpand description
Render a regression table to a string, mirroring the layout of
render_table.
pub fn render_regression_table(rows: &[Regression]) -> StringRender a regression table to a string, mirroring the layout of
render_table.