pub fn render_table(results: &[OperationResult]) -> StringExpand description
Render a results table to a string in the same shape used in the
PERFORMANCE.md “Operator Self-Verification” example.
pub fn render_table(results: &[OperationResult]) -> StringRender a results table to a string in the same shape used in the
PERFORMANCE.md “Operator Self-Verification” example.