pub struct ResolvedTtl {
pub short_ttl_secs: Option<i64>,
pub mid_ttl_secs: Option<i64>,
pub long_ttl_secs: Option<i64>,
pub short_extend_secs: i64,
pub mid_extend_secs: i64,
}Expand description
Resolved TTL values after merging config overrides with compiled defaults.
Fields
short_ttl_secs: Option<i64>mid_ttl_secs: Option<i64>long_ttl_secs: Option<i64>short_extend_secs: i64mid_extend_secs: i64Implementations
Sourceimpl ResolvedTtl
impl ResolvedTtl
Sourcepub fn from_config(cfg: Option<&TtlConfig>) -> Self
pub fn from_config(cfg: Option<&TtlConfig>) -> Self
Build from optional config overrides, falling back to compiled defaults.
TTL values are clamped to MAX_TTL_SECS (10 years) to prevent overflow.
Extension values are clamped to non-negative.
Sourcepub fn ttl_for_tier(&self, tier: &Tier) -> Option<i64>
pub fn ttl_for_tier(&self, tier: &Tier) -> Option<i64>
Get the default TTL for a given tier.
Sourcepub fn extend_for_tier(&self, tier: &Tier) -> Option<i64>
pub fn extend_for_tier(&self, tier: &Tier) -> Option<i64>
Get the TTL extension on access for a given tier.