FeatureTier

Enum FeatureTier 

pub enum FeatureTier {
    Keyword,
    Semantic,
    Smart,
    Autonomous,
}
Feature tiers control which AI capabilities are active based on the available memory budget on the host machine.

Variants



Keyword

FTS5 keyword search only — 0 MB extra.



Semantic

MiniLM embeddings + HNSW index — ~256 MB.



Smart

nomic-embed + Gemma 4 E2B via Ollama — ~1 GB.



Autonomous

nomic-embed + Gemma 4 E4B + cross-encoder via Ollama — ~4 GB.

Implementations

Source

impl FeatureTier

pub fn from_str(s: &str) -> Option<Self>

Parse a tier name (case-insensitive).

pub fn as_str(&self) -> &str

Canonical lowercase name.

pub fn config(self) -> TierConfig

Build the full TierConfig for this tier.

pub fn from_memory_budget(mb: usize) -> Self

Automatically select the best tier that fits within mb megabytes.